from botty_core import App

from .config import BOT_TOKEN

app = App(BOT_TOKEN)
